<?php

namespace Drupal\wp_publish\Batch;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\wp_publish\Service\WpPublishService;

/**
 * Batch operations for bulk publishing nodes to WordPress.
 */
class WpPublishBatch {
  use StringTranslationTrait;

  /**
   * Processes a node for publishing to WordPress.
   *
   * @param int $nid
   *   The node ID.
   * @param \Drupal\wp_publish\Service\WpPublishService $publish_service
   *   The WordPress publishing service.
   * @param array $context
   *   The batch context.
   */
  public static function publishNode($nid, WpPublishService $publish_service, &$context) {
    $node = \Drupal\node\Entity\Node::load($nid);
    if ($node && $node->isPublished() && $node->get('wp_publish')->value) {
      $publish_service->publishNode($node);
      $context['results'][] = $nid;
      $context['message'] = t('Published node @nid to WordPress.', ['@nid' => $nid]);
    }
  }

  /**
   * Finishes the batch process.
   *
   * @param bool $success
   *   Whether the batch was successful.
   * @param array $results
   *   The batch results.
   * @param array $operations
   *   The batch operations.
   */
  public static function finish($success, $results, $operations) {
    if ($success) {
      $message = t('Successfully published @count nodes to WordPress.', ['@count' => count($results)]);
    }
    else {
      $message = t('An error occurred during bulk publishing.');
    }
    \Drupal::messenger()->addMessage($message);
  }
}
