<?php

namespace Drupal\wp_publish\EventSubscriber;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\node\NodeInterface;
use Drupal\wp_publish\Service\WpPublishService;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;
use Drupal\node\Event\NodeEvent;
use Drupal\node\Event\NodeEvents;

/**
 * Event subscriber to publish nodes to WordPress on save.
 */
class WpPublishSubscriber implements EventSubscriberInterface {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The WordPress publishing service.
   *
   * @var \Drupal\wp_publish\Service\WpPublishService
   */
  protected $wpPublishService;

  /**
   * Constructs a WpPublishSubscriber object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Drupal\wp_publish\Service\WpPublishService $wp_publish_service
   *   The WordPress publishing service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, WpPublishService $wp_publish_service) {
    $this->configFactory = $config_factory;
    $this->wpPublishService = $wp_publish_service;
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents() {
    return [
      NodeEvents::PRESAVE => 'onNodePresave',
    ];
  }

  /**
   * Publishes a node to WordPress when saved, if conditions are met.
   *
   * @param \Drupal\node\Event\NodeEvent $event
   *   The node event.
   */
  public function onNodePresave(NodeEvent $event) {
    $node = $event->getNode();
    $config = $this->configFactory->get('wp_publish.settings');
    $enabled_types = $config->get('enabled_content_types') ?? [];

    if (
      $node instanceof NodeInterface &&
      $node->isPublished() &&
      in_array($node->getType(), $enabled_types) &&
      $node->get('wp_publish')->value
    ) {
      $this->wpPublishService->publishNode($node);
    }
  }
}
